==> zio-aws-storagegateway_3-5.17.116.2-sources.jar: zio/aws/storagegateway/model/UpdateAutomaticTapeCreationPolicyResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateAutomaticTapeCreationPolicyResponse(
    gatewayARN: Option[GatewayARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse = {
    import UpdateAutomaticTapeCreationPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly =
    zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
      .wrap(buildAwsValue())
}
object UpdateAutomaticTapeCreationPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse =
      zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse(
        gatewayARN.map(value => value)
      )
    def gatewayARN: Option[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ) extends zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly {
    override val gatewayARN: Option[GatewayARN] = scala
      .Option(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ): zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_3-5.17.191.2-sources.jar: zio/aws/storagegateway/model/UpdateAutomaticTapeCreationPolicyResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateAutomaticTapeCreationPolicyResponse(
    gatewayARN: Optional[GatewayARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse = {
    import UpdateAutomaticTapeCreationPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly =
    zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
      .wrap(buildAwsValue())
}
object UpdateAutomaticTapeCreationPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse =
      zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse(
        gatewayARN.map(value => value)
      )
    def gatewayARN: Optional[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ) extends zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly {
    override val gatewayARN: Optional[GatewayARN] = zio.aws.core.internal
      .optionalFromNullable(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse
  ): zio.aws.storagegateway.model.UpdateAutomaticTapeCreationPolicyResponse.ReadOnly =
    new Wrapper(impl)
}
